@@ -307,7 +307,7 @@ class Taiyi:
         elif se_jc !=1 and ty_jc !=1 and se_jc1 !=1 :
             return sum(se_order[: se_order.index(ty)])
         elif se_jc !=1 and ty_jc !=1 and se_jc1 !=1 and se_num != ty:
-            return sum(sf_order[: sf_order.index(ty)])
+            return sum(se_order[: se_order.index(ty)])
         elif se_jc !=1 and ty_jc !=1 and se_jc1 !=1 and se_num == ty:
             return ty
     
@@ -559,6 +559,118 @@ class Taiyi:
                 "九宮":self.nine_gong(), 
                 "十六宮":self.sixteen_gong(),
                 }
+        
+    def html(self):
+        text = '''<html><body><table border="0" cellpadding="1" cellspacing="1" style="width:500px">
+    	<tbody>
+    		<tr>
+    			<td colspan="5">
+    			<p><span style="font-size:large"><strong>'''+str(self.year)+"年"+str(self.month)+"月"+str(self.day)+"日"+str(self.hour)+"時"+'''<br />
+    			干支: '''+self.gangzhi()[0]+"  "+self.gangzhi()[1]+"  "+self.gangzhi()[2]+"  "+self.gangzhi()[3]+'''&nbsp;</strong></span></p>
+    			<p><span style="font-size:large"><strong>'''+self.jiyuan()+"  "+self.kook()+'''<br />
+    			主算:'''+str(self.home_cal())+"".join(self.cal_des(self.home_cal()))+'''<br />
+    			客算:'''+str(self.away_cal())+"".join(self.cal_des(self.away_cal()))+'''<br />
+    			定算:'''+str(self.set_cal())+"".join(self.cal_des(self.set_cal()))+'''</strong></span></p>
+    			</td>
+    		</tr>
+    		<tr>
+    			<td><span style="font-size:large"><strong>巽</strong></span>
+    			<table border="0" cellpadding="1" cellspacing="1" style="width:100px">
+    				<tbody>'''+"".join(['''<tr><td>'''+i+'''</td></tr>''' for i in self.pan().get("十六宮").get("巽")])+'''</tbody>
+    			</table>
+    			</td>
+    			<td><span style="font-size:large"><strong>巳</strong></span>
+    			<table border="0" cellpadding="1" cellspacing="1" style="width:100px">
+    				<tbody>'''+"".join(['''<tr><td>'''+i+'''</td></tr>''' for i in self.pan().get("十六宮").get("巳")])+'''</tbody>
+    			</table>
+    			</td>
+    			<td><span style="font-size:large"><strong>午</strong></span>
+    			<table border="0" cellpadding="1" cellspacing="1" style="width:100px">
+    				<tbody>'''+"".join(['''<tr><td>'''+i+'''</td></tr>''' for i in self.pan().get("十六宮").get("午")])+'''</tbody>
+    			</table>
+    			</td>
+    			<td><span style="font-size:large"><strong>未&nbsp;</strong></span>
+    			<table border="0" cellpadding="1" cellspacing="1" style="width:100px">
+    				<tbody>'''+"".join(['''<tr><td>'''+i+'''</td></tr>''' for i in self.pan().get("十六宮").get("未")])+'''</tbody>
+    			</table>
+    			</td>
+    			<td><span style="font-size:large"><strong>坤</strong></span>
+    			<table border="0" cellpadding="1" cellspacing="1" style="width:100px">
+    				<tbody>'''+"".join(['''<tr><td>'''+i+'''</td></tr>''' for i in self.pan().get("十六宮").get("坤")])+'''</tbody>
+    			</table>
+    			</td>
+    		</tr>
+    		<tr>
+    			<td><span style="font-size:large"><strong>辰</strong></span>
+    			<table border="0" cellpadding="1" cellspacing="1" style="width:100px">
+    				<tbody>'''+"".join(['''<tr><td>'''+i+'''</td></tr>''' for i in self.pan().get("十六宮").get("辰")])+'''</tbody>
+    			</table>
+    			</td>
+    			<td colspan="3" rowspan="3">&nbsp;</td>
+    			<td><span style="font-size:large"><strong>申</strong></span>
+    			<table border="0" cellpadding="1" cellspacing="1" style="width:100px">
+    				<tbody>'''+"".join(['''<tr><td>'''+i+'''</td></tr>''' for i in self.pan().get("十六宮").get("申")])+'''</tbody>
+    			</table>
+    			</td>
+    		</tr>
+    		<tr>
+    			<td><span style="font-size:large"><strong>卯</strong></span>
+    			<table border="0" cellpadding="1" cellspacing="1" style="width:100px">
+    				<tbody>'''+"".join(['''<tr><td>'''+i+'''</td></tr>''' for i in self.pan().get("十六宮").get("卯")])+'''</tbody>
+    			</table>
+    			</td>
+    			<td><span style="font-size:large"><strong>酉</strong></span>
+    			<table border="0" cellpadding="1" cellspacing="1" style="width:100px">
+    				<tbody>'''+"".join(['''<tr><td>'''+i+'''</td></tr>''' for i in self.pan().get("十六宮").get("酉")])+'''</tbody>
+    			</table>
+    			</td>
+    		</tr>
+    		<tr>
+    			<td><span style="font-size:large"><strong>寅</strong></span>
+    			<table border="0" cellpadding="1" cellspacing="1" style="width:100px">
+    				<tbody>'''+"".join(['''<tr><td>'''+i+'''</td></tr>''' for i in self.pan().get("十六宮").get("寅")])+'''</tbody>
+    			</table>
+    			</td>
+    			<td><span style="font-size:large"><strong>戌</strong></span>
+    			<table border="0" cellpadding="1" cellspacing="1" style="width:100px">
+    				<tbody>'''+"".join(['''<tr><td>'''+i+'''</td></tr>''' for i in self.pan().get("十六宮").get("戌")])+'''</tbody>
+    			</table>
+    			</td>
+    		</tr>
+    		<tr>
+    			<td><span style="font-size:large"><strong>艮</strong></span>
+    			<table border="0" cellpadding="1" cellspacing="1" style="width:100px">
+    				<tbody>'''+"".join(['''<tr><td>'''+i+'''</td></tr>''' for i in self.pan().get("十六宮").get("艮")])+'''</tbody>
+    			</table>
+    			</td>
+    			<td><span style="font-size:large"><strong>丑</strong></span>
+    				<table border="0" cellpadding="1" cellspacing="1" style="width:100px">
+    				<tbody>'''+"".join(['''<tr><td>'''+i+'''</td></tr>''' for i in self.pan().get("十六宮").get("丑")])+'''</tbody>
+    			</table>
+    			</td>
+    			<td><span style="font-size:large"><strong>子</strong></span>
+    			<table border="0" cellpadding="1" cellspacing="1" style="width:100px">
+    				<tbody>'''+"".join(['''<tr><td>'''+i+'''</td></tr>''' for i in self.pan().get("十六宮").get("子")])+'''</tbody>
+    			</table>
+    			</td>
+    			<td><span style="font-size:large"><strong>亥</strong></span>
+    			<table border="0" cellpadding="1" cellspacing="1" style="width:100px">
+    				<tbody>'''+"".join(['''<tr><td>'''+i+'''</td></tr>''' for i in self.pan().get("十六宮").get("亥")])+'''</tbody>
+    			</table>
+    			</td>
+    			<td><span style="font-size:large"><strong>乾</strong></span>
+    			<table border="0" cellpadding="1" cellspacing="1" style="width:100px">
+    				<tbody>'''+"".join(['''<tr><td>'''+i+'''</td></tr>''' for i in self.pan().get("十六宮").get("乾")])+'''</tbody>
+    			</table>
+    			</td>
+    		</tr>
+    	</tbody>
+    </table>
+    
+    <p>&nbsp;</p></body></html>
+         ''' 
+        return text
+	
 
 
 if __name__ == '__main__':
